@@ -45,18 +45,6 @@
 #define SEC_RING "/secring.gpg"
 #define PUB_RING "/pubring.gpg"
 
-/* Drag and trop target types */
-enum TargetTypes {
-    TEXT_PLAIN,
-    TEXT_URIS
-};
-
-/* Drag and drop targent entries */
-static const GtkTargetEntry target_entries[] = {
-   { "text/uri-list", 0, TEXT_URIS },
-   { "text/plain", 0, TEXT_PLAIN }
-};
-
 /* Quits seahorse */
 static void
 quit (GtkWidget *widget, SeahorseWidget *swidget)
@@ -160,7 +148,7 @@ copy_activate (GtkWidget *widget, SeahorseWidget *swidget)
     if (g_list_length (keys) == 0)
         return;
                
-    text = seahorse_op_export_text (keys, &err);
+    text = seahorse_op_export_text (keys, FALSE, &err);
 
     if (text == NULL)
         seahorse_util_handle_error (err, _("Couldn't export key to clipboard"));
@@ -192,18 +180,19 @@ export_activate (GtkWidget *widget, SeahorseWidget *swidget)
     gchar* uri = NULL;
     GError *err = NULL;
     GList *keys;
+
+    keys = seahorse_key_store_get_selected_keys (GTK_TREE_VIEW (
+                        glade_xml_get_widget (swidget->xml, KEY_LIST)));
     
     dialog = seahorse_util_chooser_save_new (_("Export Key"), 
                 GTK_WINDOW(glade_xml_get_widget (swidget->xml, "key-manager")));
     seahorse_util_chooser_show_key_files (dialog);
+    seahorse_util_chooser_set_filename (dialog, keys);
      
     uri = seahorse_util_chooser_save_prompt (dialog);
     if(uri) {
-        keys = seahorse_key_store_get_selected_keys (GTK_TREE_VIEW (
-            glade_xml_get_widget (swidget->xml, KEY_LIST)));
 
-        seahorse_op_export_file (keys, uri, &err); 
-		g_list_free (keys);
+        seahorse_op_export_file (keys, FALSE, uri, &err); 
 		        
         if (err != NULL)
             seahorse_util_handle_error (err, _("Couldn't export key to \"%s\""),
@@ -211,6 +200,8 @@ export_activate (GtkWidget *widget, SeahorseWidget *swidget)
                     
         g_free (uri);
     }
+    
+    g_list_free (keys);
 }
 
 /*Archives public and private keyrings*/
@@ -274,6 +265,20 @@ search_activate (GtkWidget *widget, SeahorseWidget *swidget)
 {
     seahorse_keyserver_search_show (swidget->sctx);
 }
+
+static void
+sync_activate (GtkWidget *widget, SeahorseWidget *swidget)
+{
+	GList *list = NULL;
+    GtkTreeView *view;
+    
+    view = GTK_TREE_VIEW (glade_xml_get_widget (swidget->xml, KEY_LIST));
+	
+	list = seahorse_key_store_get_selected_keys (view);
+    if (list == NULL)
+        list = seahorse_key_store_get_all_keys (view);
+    seahorse_keyserver_sync_show (swidget->sctx, list);
+}
 #endif
 
 /* Loads delete dialog if a key is selected */
@@ -305,17 +310,6 @@ delete_activate (GtkWidget *widget, SeahorseWidget *swidget)
   	g_list_free (list);
 }
 
-static void
-change_passphrase_activate (GtkMenuItem *item, SeahorseWidget *swidget)
-{
-	SeahorseKey *skey;
-	
-	skey = seahorse_key_store_get_selected_key (GTK_TREE_VIEW (
-		glade_xml_get_widget (swidget->xml, KEY_LIST)), NULL);
-	if (skey != NULL && SEAHORSE_IS_KEY_PAIR (skey))
-		seahorse_key_pair_op_change_pass (SEAHORSE_KEY_PAIR (skey));
-}
-
 static void
 add_uid_activate (GtkMenuItem *item, SeahorseWidget *swidget)
 {
@@ -353,7 +347,7 @@ add_revoker_activate (GtkMenuItem *item, SeahorseWidget *swidget)
 static void
 preferences_activate (GtkWidget *widget, SeahorseWidget *swidget)
 {
-	seahorse_preferences_show (swidget->sctx);
+	seahorse_preferences_show (swidget->sctx, 0);
 }
 
 static void
@@ -467,14 +461,8 @@ set_key_options_sensitive (SeahorseWidget *swidget, gboolean selected, gboolean
 	gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "add_uid"), create);
 	gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "key_add_uid"), create);
 	
-	create = (secret && seahorse_key_widget_can_create ("add-subkey", skey));
-	gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "add_subkey"), create);
-	gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "key_add_subkey"), create);
-	
 	gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "add_revoker"), secret);
-	gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "key_change_passphrase"), secret);
 	gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "key_add_revoker"), secret);
-	gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "change_passphrase"), secret);
 }
 
 static void
@@ -625,12 +613,13 @@ seahorse_key_manager_show (SeahorseContext *sctx)
 		"context_menu", NULL);
 	set_key_options_sensitive (swidget, FALSE, FALSE, NULL);
 	
-	//features not available
-	gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "add_photo"), FALSE);
-	gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "key_add_photo"), FALSE);
+	/* features not available */
 	gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "gen_revoke"), FALSE);
 	gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "key_gen_revoke"), FALSE);
 
+	w = glade_xml_get_widget (swidget->xml, "toolbar");
+	gtk_toolbar_unset_style (GTK_TOOLBAR (w));
+
     glade_xml_signal_connect_data (swidget->xml, "backup_activate",
         G_CALLBACK (backup_activate), swidget);
 	
@@ -650,9 +639,14 @@ seahorse_key_manager_show (SeahorseContext *sctx)
 #ifdef WITH_KEYSERVER      
     glade_xml_signal_connect_data (swidget->xml, "search_activate",
                                    G_CALLBACK (search_activate), swidget);
+    glade_xml_signal_connect_data (swidget->xml, "sync_activate",
+                                   G_CALLBACK (sync_activate), swidget);
 #else
+    gtk_widget_hide (glade_xml_get_widget (swidget->xml, "remote_menu"));    
     gtk_widget_hide (glade_xml_get_widget (swidget->xml, "search_button"));    
     gtk_widget_hide (glade_xml_get_widget (swidget->xml, "keyserver_search"));    
+    gtk_widget_hide (glade_xml_get_widget (swidget->xml, "keyserver_sync"));    
+    gtk_widget_hide (glade_xml_get_widget (swidget->xml, "key_sync"));    
 #endif	
 
 	glade_xml_signal_connect_data (swidget->xml, "expand_all_activate",
@@ -667,6 +661,7 @@ seahorse_key_manager_show (SeahorseContext *sctx)
 		G_CALLBACK (key_list_button_pressed), swidget);
 	glade_xml_signal_connect_data (swidget->xml, "key_list_popup_menu",
 		G_CALLBACK (key_list_popup_menu), swidget);
+        
 	/* selected key signals */
 	glade_xml_signal_connect_data (swidget->xml, "properties_activate",
 		G_CALLBACK (properties_activate), swidget);
@@ -678,9 +673,8 @@ seahorse_key_manager_show (SeahorseContext *sctx)
 		G_CALLBACK (delete_activate), swidget);
     glade_xml_signal_connect_data (swidget->xml, "copy_activate",
         G_CALLBACK (copy_activate), swidget);      
+        
 	/* selected key with secret signals */
-	glade_xml_signal_connect_data (swidget->xml, "change_passphrase_activate",
-		G_CALLBACK (change_passphrase_activate), swidget);
 	glade_xml_signal_connect_data (swidget->xml, "add_uid_activate",
 		G_CALLBACK (add_uid_activate), swidget);
 	glade_xml_signal_connect_data (swidget->xml, "add_subkey_activate",
@@ -713,24 +707,24 @@ seahorse_key_manager_show (SeahorseContext *sctx)
 		G_CALLBACK (selection_changed), swidget);
     skstore = seahorse_key_manager_store_new (sksrc, view);
 	selection_changed (selection, swidget);
-   
+
     /* Setup drops */
-    gtk_drag_dest_set (GTK_WIDGET (win), GTK_DEST_DEFAULT_ALL, target_entries, 
-            sizeof (target_entries) / sizeof (target_entries[0]), GDK_ACTION_COPY);
+    gtk_drag_dest_set (GTK_WIDGET (win), GTK_DEST_DEFAULT_ALL, 
+                seahorse_target_entries, seahorse_n_targets, GDK_ACTION_COPY);
     gtk_signal_connect (GTK_OBJECT (win), "drag_data_received",
-            GTK_SIGNAL_FUNC (target_drag_data_received), sctx);
+                GTK_SIGNAL_FUNC (target_drag_data_received), sctx);
                         
     /* For the filtering */
     glade_xml_signal_connect_data(swidget->xml, "on_filter_changed",
-                              G_CALLBACK(filter_changed), skstore);
+                G_CALLBACK(filter_changed), skstore);
 
     /* Hook progress bar in */
     operation = seahorse_key_source_get_operation (sksrc);
     g_return_val_if_fail (operation != NULL, win);
     
     w = glade_xml_get_widget (swidget->xml, "status");
-    seahorse_progress_appbar_add_operation (w, operation);
-    
+    seahorse_progress_appbar_set_operation (w, operation);
+
     /* Although not all the keys have completed we'll know whether we have 
      * any or not at this point */
 	if (seahorse_key_source_get_count (sksrc, FALSE) == 0) {
